<?php

/**
 * Plugin Name:       Cylindo Curator - Woocommerce
 * Description:       Cylindo Curator Plugin for Woocommerce
 * Plugin URI:        https://learn.cylindo.com/hc/en-us
 * Version:           1.0.0
 * Author:            WooThemes, Cylindo
 * Author URI:        https://www.woocommerce.com/
 * Text Domain:		  cylindo-curator
 * Requires at least: 3.0.0
 * Tested up to:      4.4.2
 *
 * @package Cylindo Viewer
 */

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

/**
 * Main Cylindo_Curator Class
 *
 * @class Cylindo_Curator
 * @version	1.0.0
 * @since 1.0.0
 * @package	Cylindo_Curator
 */
final class Cylindo_Curator
{

	/**
	 * Set up the plugin
	 */
	public function __construct()
	{
		add_action('init', array($this, 'cylindo_curator_setup'), -1);
		require_once('core/functions.php');
	}

	/**
	 * Setup all the things
	 */
	public function cylindo_curator_setup()
	{
		add_action('wp_enqueue_scripts', array($this, 'cylindo_curator_css'), 999);
		add_action('wp_enqueue_scripts', array($this, 'cylindo_curator_js'));
		add_filter('template_include',   array($this, 'cylindo_curator_template'), 11);
		add_filter('wc_get_template',    array($this, 'cylindo_curator_wc_get_template'), 11, 5);
	}

	/**
	 * Enqueue the CSS
	 *
	 * @return void
	 */
	public function cylindo_curator_css()
	{
		wp_enqueue_style('viewer-css', plugins_url('/core/style.css', __FILE__));
	}

	/**
	 * Enqueue the Javascript
	 *
	 * @return void
	 */
	public function cylindo_curator_js()
	{
		wp_enqueue_script('viewer-js', plugins_url('/core/index.js', __FILE__), array('jquery'));
	}

	/**
	 * Look in this plugin for template files first.
	 * This works for the top level templates (IE single.php, page.php etc). However, it doesn't work for
	 * template parts yet (content.php, header.php etc).
	 *
	 * Relevant trac ticket; https://core.trac.wordpress.org/ticket/13239
	 *
	 * @param  string $template template string.
	 * @return string $template new template string.
	 */
	public function cylindo_curator_template($template)
	{
		if (file_exists(untrailingslashit(plugin_dir_path(__FILE__)) . '/core/templates/' . basename($template))) {
			$template = untrailingslashit(plugin_dir_path(__FILE__)) . '/core/templates/' . basename($template);
		}

		return $template;
	}

	/**
	 * Look in this plugin for WooCommerce template overrides.
	 *
	 * For example, if you want to override woocommerce/templates/cart/cart.php, you
	 * can place the modified template in <plugindir>/custom/templates/woocommerce/cart/cart.php
	 *
	 * @param string $located is the currently located template, if any was found so far.
	 * @param string $template_name is the name of the template (ex: cart/cart.php).
	 * @return string $located is the newly located template if one was found, otherwise
	 *                         it is the previously found template.
	 */
	public function cylindo_curator_wc_get_template($located, $template_name, $args, $template_path, $default_path)
	{
		$plugin_template_path = untrailingslashit(plugin_dir_path(__FILE__)) . '/core/templates/woocommerce/' . $template_name;

		if (file_exists($plugin_template_path)) {
			$located = $plugin_template_path;
		}

		return $located;
	}
} // End Class

/**
 * The 'main' function
 *
 * @return void
 */
function cylindo_curator_main()
{
	new Cylindo_Curator();
}

// Test to see if WooCommerce is active (including network activated).
$plugin_path = trailingslashit(WP_PLUGIN_DIR) . 'woocommerce/woocommerce.php';

if (
	in_array($plugin_path, wp_get_active_and_valid_plugins())
	|| in_array($plugin_path, wp_get_active_network_plugins())
) {
	/**
	 * Initialise the plugin
	 */
	add_action('plugins_loaded', 'cylindo_curator_main');
}
